# -*- coding: utf-8 -*-

from django.db import models
from django.utils.translation import ugettext_lazy as _

from jmb.core.db.models import DateModel, UserModel, StatusModel, OrderedModel


class Currency(DateModel, UserModel, StatusModel, OrderedModel):
    """
    Stores currencies
    """
    code = models.CharField(
        primary_key=True,
        max_length=15,
        verbose_name=_('code'),
    )
    name = models.CharField(
        unique=True,
        max_length=100,
        verbose_name=_('name'),
    )
    slug = models.SlugField(
        unique=True,
        max_length=100,
        verbose_name=_("slug"),
        help_text=_("used for URLs, auto-generated from name if blank"),
    )
    symbol = models.CharField(
        max_length=3,
        verbose_name=_('symbol'),
    )

    class Meta:
        verbose_name = _('currency')
        verbose_name_plural = _('currencies')
        ordering = ('ordering', 'code')

    def __unicode__(self):
        return u"{}".format(self.name)
